#define _CRT_SECURE_NO_WARNINGS

#include <stdio.h>
#include <stdlib.h>

#define N 2222
static int R, C, P, Q;

static void ERROR (const char *S) {
	printf("Error : %s\n", S);
	exit(1);
}

static int NOW;

#define limit_paint_calls 5000

static int paintX[limit_paint_calls + 10], paintY[limit_paint_calls + 10];
static int paint_calls;
static unsigned int used[N][(N+31)>>5];

void paint (int a, int b) {
	if(NOW != 1) {
		printf("Error : you can call paint() only in ainta()\n");
		exit(1);
	}
	if(a < 0 || a >= N) {
		printf("Error : paint(%d, %d) - a is not in [%d, %d]\n", a, b, 0, N-1);
		exit(1);
	}
	if(b < 0 || b >= N) {
		printf("Error : paint(%d, %d) - b is not in [%d, %d]\n", a, b, 0, N-1);
		exit(1);
	}

	if(paint_calls == limit_paint_calls) {
		printf("Error : too many paint() calls\n");
		exit(1);
	}
	
	paintX[paint_calls] = (R + a) % N;
	paintY[paint_calls] = (C + b) % N;
	paint_calls++;
}

#undef limit_paint_calls

#define limit_count_calls 5000
static int count_calls;
static int cnt_row[N], cnt_col[N];
static void count_increment(const char *func) {
	if(NOW == 3) {
		printf("Error : you can't call count_%s() after calling report()", func);
		exit(1);
	}
	if(NOW != 2) {
		printf("Error : you can call count_%s() only in sangsoo()\n", func);
		exit(1);
	}
	if(count_calls == limit_count_calls) {
		printf("Error : too many count_%s() calls\n", func);
		exit(1);
	}else if(count_calls < paint_calls){
		int r = paintX[count_calls];
		int c = paintY[count_calls];
		if(((used[r][c>>5] >> (c&31)) & 1) == 0) {
			++cnt_row[r];
			++cnt_col[c];
			used[r][c>>5] |= (unsigned int)1<<(c&31);
		}
	}
	++count_calls;
}


int count_row (int a) {
	if(a < 0 || a >= N) {
		printf("Error : count_row(%d) - a is not in [%d, %d].\n", a, 0, N-1);
		exit(1);
	}
	count_increment("row");
	return cnt_row[(P + a) % N];
}

int count_col (int b) {
	if(b < 0 || b >= N) {
		printf("Error : count_col(%d) - b is not in [%d, %d].\n", b, 0, N-1);
		exit(1);
	}
	count_increment("col");
	return cnt_col[(Q + b) % N];
}

static int reported = 0;
static int reported_x, reported_y;
void report (int x, int y) {
	if(reported == 1) {
		printf("Error : you cannot call report() twice");
		exit(1);
	}
	if(NOW != 2) {
		printf("Error : you can call report() only in sangsoo()\n");
		exit(1);
	}
	reported = 1;
	NOW = 3;
	reported_x = x;
	reported_y = y;
}

#undef limit_count_calls 

void ainta();
void sangsoo();

static int T;

int main() {
	int i, max_calls = -1;

	if(scanf("%d", &T) != 1) {
		ERROR("the number of test cases must be given in the first line of the input");
	}

	if(T < 1) {
		ERROR("the number of test cases must be greater than or equal to 1");
	}

	while(T--) {

		if(scanf("%d%d%d%d", &R, &C, &P, &Q) != 4) {
			ERROR("two distinct coordinates must be given in the input");
		}
		if(R < 0 || C >= N) {
			printf("Error : ainta's row number(%d) is not in [0, %d]\n", R, 0, N-1);
			exit(1);
		}
		if(C < 0 || C >= N) {
			printf("Error : ainta's column number(%d) is not in [0, %d]\n", C, 0, N-1);
			exit(1);
		}
		if(P < 0 || P >= N) {
			printf("Error : sangsoo's row number(%d) is not in [0, %d]\n", P, 0, N-1);
			exit(1);
		}
		if(Q < 0 || Q >= N) {
			printf("Error : sangsoo's column number(%d) is not in the range [0, %d]\n",Q, 0, N-1);
			exit(1);
		}
		if(R == P && C == Q) {
			printf("Error : the position of ainta and the position of sangsoo must be different\n");
			exit(1);
		}

		NOW = 1;
		ainta();

		NOW = 2;
		sangsoo();
	
		if(!reported) {
			printf("Error : report() must be called at least once\n");
			exit(1);
		}

		{
			int ans_x = (R - P + N) % N;
			int ans_y = (C - Q + N) % N;
	
			if(ans_x == reported_x && ans_y == reported_y) {
				if(max_calls < count_calls) max_calls = count_calls;
				if(max_calls < paint_calls) max_calls = paint_calls;
			}else {
				printf("WRONG\n");
				printf("data : r = %d, c = %d, p = %d, q = %d\n", R,C,P,Q);
				printf("answer : %d %d\n", ans_x, ans_y);
				printf("yours  : %d %d\n", reported_x, reported_y);
				printf("number of paint calls = %d\n", paint_calls);
				printf("number of count calls = %d\n", count_calls);
				return 0;
			}
		}

		for(i = 0; i < paint_calls; i++) {
			int r = paintX[i];
			int c = paintY[i];
			cnt_row[r] = cnt_col[c] = 0;
			used[r][c>>5] = 0;
		}

		paint_calls = 0;
		count_calls = 0;
		reported = 0;
	}

	printf("Correct!\n");
	printf("maximum number of calls = %d\n", max_calls);
	return 0;
}